States
======

.. _State_Subtypes:


.. toctree::
   :maxdepth: 1

   *Subclasses:*
   InputState
   ParameterState
   OutputState
   ModulatorySignals <ModulatorySignal>

.. automodule:: psyneulink.core.components.states.state
   :members:
   :exclude-members: random, update, Parameters

